==> haskell-openglraw_3.2.1.0.orig.tar.gz: OpenGLRaw-3.2.1.0/src/Graphics/GL/Functions.hs <==
--------------------------------------------------------------------------------
-- |
-- Module      :  Graphics.GL.Functions
-- Copyright   :  (c) Sven Panne 2016
-- License     :  BSD3
--
-- Maintainer  :  Sven Panne <svenpanne@gmail.com>
-- Stability   :  stable
-- Portability :  portable
--
-- All raw functions from the
-- <http://www.opengl.org/registry/ OpenGL registry>.
--
--------------------------------------------------------------------------------

module Graphics.GL.Functions (
  module Graphics.GL.Functions.F01,
  module Graphics.GL.Functions.F02,
  module Graphics.GL.Functions.F03,
  module Graphics.GL.Functions.F04,
  module Graphics.GL.Functions.F05,
  module Graphics.GL.Functions.F06,
  module Graphics.GL.Functions.F07,
  module Graphics.GL.Functions.F08,
  module Graphics.GL.Functions.F09,
  module Graphics.GL.Functions.F10,
  module Graphics.GL.Functions.F11,
  module Graphics.GL.Functions.F12,
  module Graphics.GL.Functions.F13,
  module Graphics.GL.Functions.F14,
  module Graphics.GL.Functions.F15,
  module Graphics.GL.Functions.F16,
  module Graphics.GL.Functions.F17,
  module Graphics.GL.Functions.F18,
  module Graphics.GL.Functions.F19,
  module Graphics.GL.Functions.F20,
  module Graphics.GL.Functions.F21,
  module Graphics.GL.Functions.F22,
  module Graphics.GL.Functions.F23,
  module Graphics.GL.Functions.F24,
  module Graphics.GL.Functions.F25,
  module Graphics.GL.Functions.F26,
  module Graphics.GL.Functions.F27,
  module Graphics.GL.Functions.F28,
  module Graphics.GL.Functions.F29,
  module Graphics.GL.Functions.F30,
  module Graphics.GL.Functions.F31,
  module Graphics.GL.Functions.F32
) where

import Graphics.GL.Functions.F01
import Graphics.GL.Functions.F02
import Graphics.GL.Functions.F03
import Graphics.GL.Functions.F04
import Graphics.GL.Functions.F05
import Graphics.GL.Functions.F06
import Graphics.GL.Functions.F07
import Graphics.GL.Functions.F08
import Graphics.GL.Functions.F09
import Graphics.GL.Functions.F10
import Graphics.GL.Functions.F11
import Graphics.GL.Functions.F12
import Graphics.GL.Functions.F13
import Graphics.GL.Functions.F14
import Graphics.GL.Functions.F15
import Graphics.GL.Functions.F16
import Graphics.GL.Functions.F17
import Graphics.GL.Functions.F18
import Graphics.GL.Functions.F19
import Graphics.GL.Functions.F20
import Graphics.GL.Functions.F21
import Graphics.GL.Functions.F22
import Graphics.GL.Functions.F23
import Graphics.GL.Functions.F24
import Graphics.GL.Functions.F25
import Graphics.GL.Functions.F26
import Graphics.GL.Functions.F27
import Graphics.GL.Functions.F28
import Graphics.GL.Functions.F29
import Graphics.GL.Functions.F30
import Graphics.GL.Functions.F31
import Graphics.GL.Functions.F32

==> haskell-openglraw_3.2.5.0.orig.tar.gz: OpenGLRaw-3.2.5.0/src/Graphics/GL/Functions.hs <==
--------------------------------------------------------------------------------
-- |
-- Module      :  Graphics.GL.Functions
-- Copyright   :  (c) Sven Panne 2016
-- License     :  BSD3
--
-- Maintainer  :  Sven Panne <svenpanne@gmail.com>
-- Stability   :  stable
-- Portability :  portable
--
-- All raw functions from the
-- <http://www.opengl.org/registry/ OpenGL registry>.
--
--------------------------------------------------------------------------------

module Graphics.GL.Functions (
  module Graphics.GL.Functions.F01,
  module Graphics.GL.Functions.F02,
  module Graphics.GL.Functions.F03,
  module Graphics.GL.Functions.F04,
  module Graphics.GL.Functions.F05,
  module Graphics.GL.Functions.F06,
  module Graphics.GL.Functions.F07,
  module Graphics.GL.Functions.F08,
  module Graphics.GL.Functions.F09,
  module Graphics.GL.Functions.F10,
  module Graphics.GL.Functions.F11,
  module Graphics.GL.Functions.F12,
  module Graphics.GL.Functions.F13,
  module Graphics.GL.Functions.F14,
  module Graphics.GL.Functions.F15,
  module Graphics.GL.Functions.F16,
  module Graphics.GL.Functions.F17,
  module Graphics.GL.Functions.F18,
  module Graphics.GL.Functions.F19,
  module Graphics.GL.Functions.F20,
  module Graphics.GL.Functions.F21,
  module Graphics.GL.Functions.F22,
  module Graphics.GL.Functions.F23,
  module Graphics.GL.Functions.F24,
  module Graphics.GL.Functions.F25,
  module Graphics.GL.Functions.F26,
  module Graphics.GL.Functions.F27,
  module Graphics.GL.Functions.F28,
  module Graphics.GL.Functions.F29,
  module Graphics.GL.Functions.F30,
  module Graphics.GL.Functions.F31,
  module Graphics.GL.Functions.F32,
  module Graphics.GL.Functions.F33
) where

import Graphics.GL.Functions.F01
import Graphics.GL.Functions.F02
import Graphics.GL.Functions.F03
import Graphics.GL.Functions.F04
import Graphics.GL.Functions.F05
import Graphics.GL.Functions.F06
import Graphics.GL.Functions.F07
import Graphics.GL.Functions.F08
import Graphics.GL.Functions.F09
import Graphics.GL.Functions.F10
import Graphics.GL.Functions.F11
import Graphics.GL.Functions.F12
import Graphics.GL.Functions.F13
import Graphics.GL.Functions.F14
import Graphics.GL.Functions.F15
import Graphics.GL.Functions.F16
import Graphics.GL.Functions.F17
import Graphics.GL.Functions.F18
import Graphics.GL.Functions.F19
import Graphics.GL.Functions.F20
import Graphics.GL.Functions.F21
import Graphics.GL.Functions.F22
import Graphics.GL.Functions.F23
import Graphics.GL.Functions.F24
import Graphics.GL.Functions.F25
import Graphics.GL.Functions.F26
import Graphics.GL.Functions.F27
import Graphics.GL.Functions.F28
import Graphics.GL.Functions.F29
import Graphics.GL.Functions.F30
import Graphics.GL.Functions.F31
import Graphics.GL.Functions.F32
import Graphics.GL.Functions.F33
